@@ -130,7 +130,7 @@ def generate_stream(schema, targets, Template, center):
         # param in generate() determined by the setup in template
         stream = Template.generate(run_groups=run_groups,
                                    file_groups=file_groups,
-                                   center='test_cneter')
+                                   center=center)
     else:
         stream = Template.generate(df=targets, center=center)
 
@@ -359,12 +359,11 @@ def get_cmd_line(schema_xmls, url, webin_id, password):
     '''
 
 
-    server = '{}%20{}%20{}'.format(url, webin_id, password)
     sources = ['-F {}=@{}'.format(schema.upper(), source)
                for schema, source in schema_xmls.items()]
     sources = ' '.join(sources)
 
-    cmd_line = 'curl -k {} {}'.format(sources, server)
+    cmd_line = 'curl -u {}:{} {} {}'.format(webin_id, password, sources, url)
 
     return cmd_line
 
